#!/bin/bash
#------------------------------------------------------------------------------

set -u

declare OldCL=
declare NewCL=
declare Description=
declare Type=
declare TypeTag=
declare AppHome=${0%/*}
declare ReleaseTag=
declare RelNotesFile
declare TmpFile=/tmp/tmp.sdp_rel_notes.$$.$RANDOM

# Micro functions.
function msg () { echo -e $*; }
function bail () { msg "Error: ${1:-Unknown Error}"; exit ${2:-1}; }
function cmd () { msg "Executing: $*"; $*; return $?; }

if [[ "$(p4 opened //guest/perforce_software/sdp/dev/Version)" != "//"* ]]; then
   bail "The Version file is not checked out. Aborting."
fi

p4 diff //guest/perforce_software/sdp/dev/Version > $TmpFile 2>&1

OldCL=$(grep '< Rev' $TmpFile|cut -d '/' -f 4)
OldCL=${OldCL%% *}
NewCL=$(grep '> Rev' $TmpFile|cut -d '/' -f 4)
NewCL=${NewCL%% *}
ReleaseTag=$(head -1 $AppHome/../dev/Version)
ReleaseTag=${ReleaseTag%\.}

if [[ "$OldCL" == "$NewCL" ]]; then
   bail "Changelist number not updated in Version file."
fi

RelNotesFile=${AppHome}/../dev/doc/ReleaseNotes.txt

if [[ -n "$(p4 -ztag -F %depotFile% files $RelNotesFile)" ]]; then
   if [[ -z "$(p4 -ztag -F %depotFile% opened $RelNotesFile)" ]]; then
      p4 edit $RelNotesFile
   else
      bail "Release notes file is checked out already. Aborting."
   fi
else
   bail "Can't identify release notes file [$RelNotesFile]. Aborting."
fi

echo -e "\nReleased: $ReleaseTag\n\nJobs Fixed between changelists $OldCL and $NewCL (F=Feature, B=Bug):\n" > $TmpFile
for j in $(p4 -ztag -F %Job% jobs //guest/perforce_software/sdp/dev/...@${OldCL},@${NewCL}); do
   Description=$(p4 -ztag -F %Description% job -o $j|head -1)
   Type=$(p4 -ztag -F %Type% job -o $j)
   case $Type in
      (Feature) TypeTag=F;;
      (Bug) TypeTag=B;;
      (*) TypeTag=$Type;;
   esac
   echo -e "$j ($TypeTag): $Description" >> $TmpFile
done

cat $TmpFile
